@@ -8,19 +8,19 @@ from .http.http_error import NotFoundError
 from .http.http_method import HttpMethod
 from .http.http_request import HttpRequest
 from .http.http_response import HttpResponse
-from .middleware.application_middleware import ApplicationMiddleware
+from .middleware.application_middleware import RequestHandlerMiddleware
 from .middleware.middleware import Middleware, MiddlewarePipeline
 from .routing import Route, Router
-from .serverless.wrapper import create_serverless_function
+from .serverless.wrapper import create_serverless_function, is_serverless
 
 
 class _Loader:
     _loaded_modules: List[str] = []
 
     @classmethod
-    def load(cls, ns: str) -> List[str]:
+    def load(cls, namespace: str) -> List[str]:
         # Take the first ns part to understand related system path
-        ns_parts = ns.split(".")
+        ns_parts = namespace.split(".")
         base_module = importlib.import_module(ns_parts[0])
         module_paths = getattr(base_module, "__path__", [getcwd()])
         base_path = module_paths[0]
@@ -76,46 +76,52 @@ class Application:
         return Route(base_uri + route, attributes)
 
     def get(self, route: str, **attributes) -> Callable:
-        return self._create_method_function(route, HttpMethod.GET, **attributes)
+        return self._create_route_handler(route, HttpMethod.GET, **attributes)
 
     def post(self, route: str, **attributes) -> Callable:
-        return self._create_method_function(route, HttpMethod.POST, **attributes)
+        return self._create_route_handler(route, HttpMethod.POST, **attributes)
 
     def put(self, route: str, **attributes) -> Callable:
-        return self._create_method_function(route, HttpMethod.PUT, **attributes)
+        return self._create_route_handler(route, HttpMethod.PUT, **attributes)
 
     def patch(self, route: str, **attributes) -> Callable:
-        return self._create_method_function(route, HttpMethod.PATCH, **attributes)
+        return self._create_route_handler(route, HttpMethod.PATCH, **attributes)
 
     def delete(self, route: str, **attributes) -> Callable:
-        return self._create_method_function(route, HttpMethod.DELETE, **attributes)
+        return self._create_route_handler(route, HttpMethod.DELETE, **attributes)
 
     def head(self, route: str, **attributes) -> Callable:
-        return self._create_method_function(route, HttpMethod.HEAD, **attributes)
+        return self._create_route_handler(route, HttpMethod.HEAD, **attributes)
 
     def options(self, route: str, **attributes) -> Callable:
-        return self._create_method_function(route, HttpMethod.OPTIONS, **attributes)
+        return self._create_route_handler(route, HttpMethod.OPTIONS, **attributes)
 
-    def _create_method_function(self, route: str, method: HttpMethod, **attributes):
+    def _create_route_handler(self, route: str, method: HttpMethod, **attributes):
         def _handler(handler: Callable) -> Callable:
-            r = self._create_route(route, attributes)
-            self._append_route(method, r, handler)
-            return create_serverless_function(handler, r, self._middleware)
+            local_route = self._create_route(route, attributes)
+            # handler = _wrap_request_handler(handler, local_route)
+            self._append_route(method, local_route, handler)
+            if is_serverless():
+                return create_serverless_function(handler, local_route, self._middleware)
+
+            return handler
 
         return _handler
 
     def any(self, route: str, **attributes) -> Callable:
         def _any(handler: Callable) -> Callable:
-            r = self._create_route(route, attributes)
-            self._append_route(HttpMethod.GET, r, handler)
-            self._append_route(HttpMethod.POST, r, handler)
-            self._append_route(HttpMethod.PUT, r, handler)
-            self._append_route(HttpMethod.PATCH, r, handler)
-            self._append_route(HttpMethod.DELETE, r, handler)
-            self._append_route(HttpMethod.HEAD, r, handler)
-            self._append_route(HttpMethod.OPTIONS, r, handler)
+            local_route = self._create_route(route, attributes)
+            self._append_route(HttpMethod.GET, local_route, handler)
+            self._append_route(HttpMethod.POST, local_route, handler)
+            self._append_route(HttpMethod.PUT, local_route, handler)
+            self._append_route(HttpMethod.PATCH, local_route, handler)
+            self._append_route(HttpMethod.DELETE, local_route, handler)
+            self._append_route(HttpMethod.HEAD, local_route, handler)
+            self._append_route(HttpMethod.OPTIONS, local_route, handler)
 
-            return create_serverless_function(handler, r, self._middleware)
+            if is_serverless():
+                return create_serverless_function(handler, local_route, self._middleware)
+            return handler
 
         return _any
 
@@ -149,19 +155,20 @@ class Application:
 
             request.attributes["__handler__"] = _handler
 
-        return self._application_middleware(request)
+        request_handler = self._request_handler
+        return request_handler(request)
 
     def use(self, namespace: str) -> None:
         try:
             self._loaded_modules = self._loaded_modules + _Loader.load(namespace)
-        except ModuleNotFoundError as e:
-            raise ApplicationError.for_invalid_namespace(namespace) from e
+        except ModuleNotFoundError as error:
+            raise ApplicationError.for_invalid_namespace(namespace) from error
 
     @property
-    def _application_middleware(self) -> MiddlewarePipeline:
+    def _request_handler(self) -> MiddlewarePipeline:
         if self._cached_middleware is None:
             middleware = MiddlewarePipeline(self._middleware.queue)
-            middleware.append(ApplicationMiddleware(self.router))
+            middleware.append(RequestHandlerMiddleware(self.router))
             self._cached_middleware = middleware
 
         return self._cached_middleware
